# Publications

Vessim started as a research project in early 2023 and has since been used in various research publications on carbon-aware applications and systems.

If you use Vessim in your research, please cite our paper:

!!! abstract "Paper"

    Philipp Wiesner, Ilja Behnke, Paul Kilian, Marvin Steinke, and Odej Kao. "[Vessim: A Testbed for Carbon-Aware Applications and Systems.](https://dl.acm.org/doi/pdf/10.1145/3727200.3727210)" _ACM SIGENERGY Energy Informatics Review 4 (5)_. 2024.

    ``` bibtex
    @article{wiesner2024vessim,
      title={Vessim: A testbed for carbon-aware applications and systems},
      author={Wiesner, Philipp and Behnke, Ilja and Kilian, Paul and Steinke, Marvin and Kao, Odej},
      journal={ACM SIGENERGY Energy Informatics Review},
      volume={4},
      number={5},
      pages={59--66},
      year={2024}
    }
    ```


For details in Vessim's software-in-the-loop simulation methodology, refer to our journal paper:

!!! abstract "Paper"

    Philipp Wiesner, Marvin Steinke, Henrik Nickel, Yazan Kitana, and Odej Kao. "[Software-in-the-Loop Simulation for Developing and Testing Carbon-Aware Applications](https://onlinelibrary.wiley.com/doi/10.1002/spe.3275)" _Software: Practice and Experience, 53 (12)_. 2023.

    ``` bibtex
    @article{wiesner2023sil,
      author = {Wiesner, Philipp and Steinke, Marvin and Nickel, Henrik and Kitana, Yazan and Kao, Odej},
      title = {Software-in-the-loop simulation for developing and testing carbon-aware applications},
      journal = {Software: Practice and Experience},
      year = {2023},
      volume = {53},
      number = {12},
      pages = {2362-2376},
      doi = {https://doi.org/10.1002/spe.3275}
    }
    ```


## Further publications using or building on Vessim

- Julius Irion, Philipp Wiesner, Jonathan Bader, and Odej Kao. "[Optimizing Microgrid Composition for Sustainable Data Centers](https://dl.acm.org/doi/full/10.1145/3731599.3767562)". Sustainable Supercomputing Workshop at SC. 2025.
- Miray Özcan, Philipp Wiesner, Philipp Weiß, and Odej Kao. "[Quantifying the Energy Consumption and Carbon Emissions of LLM Inference via Simulations](https://arxiv.org/pdf/2507.11417)". Workshop on Performance and Energy Efficiency in Concurrent and Distributed Systems (PECS) at Euro-PAR. 2025.
- Paul Kilian, Philipp Wiesner, and Odej Kao. "[Choosing the Right Battery Model for Data Center Simulations](https://arxiv.org/pdf/2506.17739)". 1st International Workshop on Low Carbon Computing (LOCO). 2024.
- Philipp Wiesner, Ramin Khalili, Dennis Grinwald, Pratik Agrawal, Lauritz Thamsen, and Odej Kao. "[FedZero: Leveraging Renewable Excess Energy in Federated Learning](https://dl.acm.org/doi/10.1145/3632775.3639589)". 15th ACM International Conference on Future and Sustainable Energy Systems (e-Energy). 2024.
